==> sds-stylelint-config-0.5.0.tgz: package/src/plugins/styling-hooks-deprecated.js <==
const stylelint = require('stylelint');
const valueParser = require('postcss-value-parser');
const chalk = require('chalk');
const metadata = require('../metadata/metadata.js');

const ruleName = 'sds-stylelint-plugin/styling-hooks-deprecated';

const deprecatedHooks = (primaryOption) => {
  return (root, result) => {
    const validOptions = stylelint.utils.validateOptions(result, ruleName, {
      actual: primaryOption,
      possible: [true],
    });
    if (!validOptions) {
      return;
    }

    root.walkDecls((decl) => {
      const parsedValue = valueParser(decl.value);

      parsedValue.walk(async (node) => {
        if (node.type !== 'word') return;
        if (node.value.startsWith('--')) {
          // Throw report if deprecated items show up
          for (const deprecated of Object.keys(metadata.deprecated)) {
            if (node.value.includes(deprecated)) {
              stylelint.utils.report({
                ruleName,
                result,
                message: `${chalk.black.bgYellow('deprecated')} The custom property ${chalk.cyan(
                  node.value,
                )} includes a  deprecated value of "${chalk.bold(
                  deprecated,
                )}", please use "${chalk.greenBright(metadata.deprecated[deprecated])}" instead.`,
                node: decl,
              });
            }
          }
        }
      });
    });
  };
};

deprecatedHooks.ruleName = ruleName;

module.exports = stylelint.createPlugin(ruleName, deprecatedHooks);

==> sds-stylelint-config-1.0.1.tgz: package/src/plugins/styling-hooks-deprecated.js <==
const stylelint = require('stylelint');
const valueParser = require('postcss-value-parser');
const chalk = require('chalk');
const metadata = require('../metadata/metadata.js');
const { isValidCustomProperty } = require('../utils');

const ruleName = 'sds-stylelint-plugin/styling-hooks-deprecated';

const deprecatedHooks = (primary, options) => {
  return (root, result) => {
    const validOptions = stylelint.utils.validateOptions(result, ruleName, {
      actual: primary,
      possible: [true],
    });
    if (!validOptions) {
      return;
    }

    root.walkDecls((decl) => {
      const parsedValue = valueParser(decl.value);
      const privateSyntax = (options && options.privateSyntax) || metadata.privateSyntax;

      parsedValue.walk(async (node) => {
        if (node.type !== 'word') return;
        if (isValidCustomProperty({ value: node.value, privateSyntax })) {
          // Throw report if deprecated items show up
          for (const deprecated of Object.keys(metadata.deprecated)) {
            if (node.value.includes(deprecated)) {
              stylelint.utils.report({
                ruleName,
                result,
                message: `${chalk.black.yellowBright('Deprecated Warning')} The custom property ${chalk.cyan(
                  node.value,
                )} includes a deprecated value of "${chalk.bold(
                  deprecated,
                )}", please use "${chalk.greenBright(metadata.deprecated[deprecated])}" instead.`,
                node: decl,
              });
            }
          }
        }
      });
    });
  };
};

deprecatedHooks.ruleName = ruleName;

module.exports = stylelint.createPlugin(ruleName, deprecatedHooks);
